Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// contains filtered or unexported fields
}
func (*Config) Get ¶
Get function read configure item value to the pointer v pointed variate by path, etc. "/ModuleA/SubModule1/itemIntArray" The type of variate that pointer v pointed to MUST be the same type with item value. JSON object type should correspond to struct or map[string]interface{} type in Golang. Get 函数按照配置项的在配置文件中的层次路径,如 "/ModuleA/SubModule1/itemIntArray", 读取配置项的值到指针变量v指向的变量中. v指向的变量必须与配置值数据类型相符,JSON对象类型应对应Golang中Struct类型或Map[string]interface{}类型.
Click to show internal directories.
Click to hide internal directories.